# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""Exception classes for fidorpy-related errors."""

from __future__ import unicode_literals


class FidorError(Exception):
    """Base class for exceptions raised by fidorpy."""


class SchemaNotFoundError(FidorError):
    """Raised when a Fidor API JSON schema is requested but doesn't exist."""


class LinkNotFoundError(FidorError):
    """Raised when a Link Description Object is requested but doesn't exist."""


class FidorAPIError(FidorError):
    """A generic HTTP 4xx or 5xx exception from the Fidor API.

    :param response: A :class:`requests.Response` instance
    """

    def __init__(self, response):
        self.response = response
        """The Fidor API's response"""
        self.status_code = response.status_code
        """The HTTP status code that was returned"""
        self.url = response.request.url
        """The URL that caused the exception"""
        self.method = response.request.method
        """The HTTP method used to make the request"""
        self.json = response.json(use_decimal=True)
        """The JSON content of the response"""

        message = self.json['error']['message']
        super(FidorAPIError, self).__init__(message)
