# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""This module provides utility functions that are used within fidorpy."""

from __future__ import unicode_literals

from io import open

import simplejson


def load_json_file(path):
    """Deserialize the JSON file specified by ``path`` to a Python object."""
    with open(path, encoding='utf-8') as fp:
        return simplejson.load(fp, use_decimal=True)


def save_json_file(json, path):
    """Serialize and save ``json`` in the file specified by ``path``."""
    with open(path, mode='w', encoding='utf-8', newline='\n') as fp:
        fp.write(simplejson.dumps(json, ensure_ascii=False, indent=2 * ' ', sort_keys=True))
        fp.write('\n')
