# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

from __future__ import unicode_literals

import os
import re
from io import open

from setuptools import find_packages, setup


CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: Implementation :: CPython',
    'Topic :: Office/Business :: Financial',
    'Topic :: Software Development :: Libraries :: Python Modules',
]

INSTALL_REQUIRES = [
    'requests >= 2.5.1',
    'certifi',
    'simplejson >= 3.6.5',
    'uritemplate >= 0.6',
    'six >= 1.9.0',
]

TESTS_REQUIRE = [
    'mock',
    'responses',
]


def read(*paths):
    here = os.path.dirname(os.path.abspath(__file__))
    path = os.path.join(here, *paths)

    with open(path, encoding='utf-8') as fp:
        return fp.read()


def find_version(*paths):
    regex = re.compile(r"^__version__ = '([^']*)'$", re.MULTILINE)
    version_file = read(*paths)
    version_match = regex.search(version_file)

    if version_match:
        return version_match.group(1)

    raise RuntimeError('Unable to find version string.')


setup(
    name='fidorpy',
    version=find_version('fidor', '__init__.py'),
    description='Fidor Bank API client for Python.',
    long_description=read('README.rst') + '\n\n' + read('HISTORY.rst'),
    url='http://www.fidorpy.org/',
    author='Tree Spread Ltd',
    author_email='dev@fidorpy.org',
    license='MPLv2.0',
    classifiers=CLASSIFIERS,
    keywords=['fidor', 'bank', 'banking', 'sepa'],
    packages=find_packages(exclude=['tests', 'tests.*']),
    install_requires=INSTALL_REQUIRES,
    include_package_data=True,
    zip_safe=False,
    test_suite='tests',
    tests_require=TESTS_REQUIRE,
)
